@@ -32,8 +32,9 @@ class searchWindow(gtk.Window):
     self.w=w
     self.connect('delete-event', lambda w,*a: w.hide() or True)
     self.last_txt = None
-    self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_DIALOG)
+    self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_UTILITY)
     self.set_modal(True)
+    self.set_deletable(True)
     self.set_title(_('Search results'))
     self.set_transient_for(w)
     vb=gtk.VBox(False,0); self.add(vb)
@@ -383,8 +384,8 @@ class othmanUi(gtk.Window, othmanCore):
 
 def main():
   exedir=os.path.dirname(sys.argv[0])
-  ld=os.path.join(exedir, 'locale')
-  if not os.path.exists(ld): ld=os.path.join(exedir,'..','share','locale')
+  ld=os.path.join(exedir,'..','share','locale')
+  if not os.path.exists(ld): ld=os.path.join(exedir, 'locale')
   gettext.install('othman', ld, unicode=0)
   w=othmanUi()
   gtk.main()
